Canonical

Trait Canonical 

pub trait Canonical { }
The canonical transformation by definition equates the linear predictor with the natural parameter of the response distribution. Implementing this trait for a link function automatically defines the trivial transformation functions.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Canonical for Logit

Source

impl Canonical for ndarray_glm::exp_link::NegRec

Source

impl Canonical for ndarray_glm::gamma_link::NegRec

Source

impl Canonical for NegRecSq