pub struct Model<M, F>where
M: Glm,
F: Float,{
pub data: Dataset<F>,
/* private fields */
}Expand description
Holds the data and configuration settings for a regression.
Fields
data: Dataset<F>The dataset
Implementations
Sourceimpl<M, F> Model<M, F>where
M: Glm,
F: Float,
impl<M, F> Model<M, F>where
M: Glm,
F: Float,
Sourcepub fn fit(&self) -> RegressionResult<Fit<'_, M, F>, F>
pub fn fit(&self) -> RegressionResult<Fit<'_, M, F>, F>
Perform the regression and return a fit object holding the results.
Sourcepub fn fit_options(&self) -> FitConfig<'_, M, F>
pub fn fit_options(&self) -> FitConfig<'_, M, F>
Fit options builder interface
Sourcepub fn with_options(&self, options: FitOptions<F>) -> FitConfig<'_, M, F>
pub fn with_options(&self, options: FitOptions<F>) -> FitConfig<'_, M, F>
An experimental interface that would allow fit options to be set externally.