pub struct ModelBuilder<M: Glm> { /* private fields */ }Expand description
Provides an interface to create the full model option struct with convenient type inference.
Implementations
Sourceimpl<M: Glm> ModelBuilder<M>
impl<M: Glm> ModelBuilder<M>
Sourcepub fn data<'a, Y, F, YD, XD>(
data_y: &'a ArrayBase<YD, Ix1>,
data_x: &'a ArrayBase<XD, Ix2>,
) -> ModelBuilderData<'a, M, Y, F>
pub fn data<'a, Y, F, YD, XD>( data_y: &'a ArrayBase<YD, Ix1>, data_x: &'a ArrayBase<XD, Ix2>, ) -> ModelBuilderData<'a, M, Y, F>
Borrow the Y and X data where each row in the arrays is a new observation, and create the full model builder with the data to allow for adjusting additional options.