pub struct Dataset<F>where
F: Float,{
pub y: Array1<F>,
pub x: Array2<F>,
pub linear_offset: Option<Array1<F>>,
pub weights: Option<Array1<F>>,
pub freqs: Option<Array1<F>>,
/* private fields */
}Fields
y: Array1<F>the observation of response data by event
x: Array2<F>the design matrix with observations in rows and covariates in columns
linear_offset: Option<Array1<F>>The offset in the linear predictor for each data point. This can be used to fix the effect of control variables.
weights: Option<Array1<F>>The variance weight of each observation (a.k.a. analytic weights)
freqs: Option<Array1<F>>The frequency of each observation (traditionally positive integers)
Implementations