pub struct ModelBuilderData<'a, M, Y, F>where
M: Glm,
Y: Yval<M>,
F: 'static + Float,{ /* private fields */ }Expand description
Holds the data and all the specifications for the model and provides functions to adjust the settings.
Implementations
Sourceimpl<'a, M, Y, F> ModelBuilderData<'a, M, Y, F>
A builder to generate a Model object
impl<'a, M, Y, F> ModelBuilderData<'a, M, Y, F>
A builder to generate a Model object
Sourcepub fn linear_offset(self, linear_offset: Array1<F>) -> Self
pub fn linear_offset(self, linear_offset: Array1<F>) -> Self
Represents an offset added to the linear predictor for each data point. This can be used to control for fixed effects or in multi-level models.
Sourcepub fn freq_weights(self, freqs: Array1<usize>) -> Self
pub fn freq_weights(self, freqs: Array1<usize>) -> Self
Frequency weights (a.k.a. counts) for each observation. Traditionally these are positive integers representing the number of times each observation appears identically.
Sourcepub fn var_weights(self, weights: Array1<F>) -> Self
pub fn var_weights(self, weights: Array1<F>) -> Self
Variance weights (a.k.a. analytic weights) of each observation. These could represent the inverse square of the uncertainties of each measurement.
Sourcepub fn no_constant(self) -> Self
pub fn no_constant(self) -> Self
Do not add a constant intercept term of 1s to the design matrix. This is rarely
recommended, so you probably don’t want to use this option unless you have a very clear
sense of why. Note that you can supply uniform or per-observation constant terms using
ModelBuilderData::linear_offset.
Sourcepub fn no_standardize(self) -> Self
pub fn no_standardize(self) -> Self
Don’t perform standarization (i.e. scale to 0-mean and 1-variance) of the design matrix. Note that the standardization is handled internally, so the reported result coefficients should be compatible with the input data directly, meaning the user shouldn’t have to interact with them.
pub fn build(self) -> RegressionResult<Model<M, F>, F>where
M: Glm,
F: Float,